yakumo.keystone.v2.user

Package yakumo :: Package keystone :: Package v2 :: Module user |
[hide private]
[frames] | no frames]

# Module user

source code

Resource class and its manager for users in Identity V2 API

Classes | [hide private]
| Resource resource class for users on Identity V2 API
| Manager manager class for users on Identity V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('username'
      , 'username', mapper.Noop), ('password', 'password', mapper.Noop), ('e
      mail', 'email', mapper.Noop), ('project', 'project_id', mapper.Resourc
      e('keystone.project')), ('is_enabled', 'enabled', mapper.Noop),]